@@ -2,8 +2,15 @@ import os
 
 from .lib.sutils import *
 
-ROOT_DIR = Path(os.environ.get('PAMOGK_ROOT_DIR', __file__)).resolve().parent
-LIB_DIR = ROOT_DIR / 'lib'
+ROOT_DIR = os.environ.get('PAMOGK_ROOT_DIR', None)
+if ROOT_DIR is not None:
+    ROOT_DIR = Path(ROOT_DIR)
+
+if not ROOT_DIR.exists() or not ROOT_DIR.is_dir():
+    log('Invalid PAMOGK_ROOT_DIR environment variable please set PAMOGK_ROOT_DIR to root of data and result folder')
+    ROOT_DIR = Path(__file__).resolve().parent
+    log('set PAMOGK_ROOT_DIR to ', ROOT_DIR)
+
 DATA_DIR = ROOT_DIR.parent / 'data'
 
 # if mosek env var is not given check custom valid paths
